import jwtDecode from 'jwt-decode'
import axios from 'axios'
import dayjs from 'dayjs'
import { useContext } from 'react'
import AppContext from '../context/AppContext'

const useAxios = () => {
  const baseURL = process.env.NEXT_PUBLIC_BACKEND_URL
  const { accessToken, logout } = useContext(AppContext)

  const axiosInstance = axios.create({
    baseURL: process.env.NEXT_PUBLIC_BACKEND_URL.replace(
      '{{lang}}',
      typeof window != 'undefined'
        ? localStorage.getItem('language')
          ? localStorage.getItem('language')
          : 'eng'
        : 'eng'
    ),
    baseURL,
    headers: {
      accept: 'application/json',
      Authorization: `Bearer ${accessToken}`
    }
  })
  axiosInstance.interceptors.request.use(async req => {
    const user = jwtDecode(accessToken)
    const isExpired = dayjs.unix(user.exp).diff(dayjs()) < 1
    if (!isExpired) {
      req.headers.Authorization = `Bearer ${accessToken}`
      
return req
    }
    logout()
  })
  
return axiosInstance
}

export default useAxios
